@@ -2,32 +2,9 @@
     keyfiltermanager.cpp
 
     This file is part of libkleopatra, the KDE keymanagement library
-    Copyright (c) 2004 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2004 Klarälvdalens Datakonsult AB
 
-    Libkleopatra is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of the
-    License, or (at your option) any later version.
-
-    Libkleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "keyfiltermanager.h"
@@ -39,8 +16,8 @@
 #include "libkleo_debug.h"
 #include "utils/formatting.h"
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 #include <KSharedConfig>
 #include <KLocalizedString>
 #include <QIcon>
@@ -52,7 +29,6 @@
 #include <QModelIndex>
 
 #include <algorithm>
-#include <vector>
 #include <climits>
 #include <functional>
 
@@ -71,7 +47,8 @@ public:
 
     int rowCount(const QModelIndex &) const override;
     QVariant data(const QModelIndex &idx, int role) const override;
-    /* upgrade to public */ using QAbstractListModel::reset;
+    /* upgrade to public */ using QAbstractListModel::beginResetModel;
+    /* upgrade to public */ using QAbstractListModel::endResetModel;
 };
 
 class AllCertificatesKeyFilter : public DefaultKeyFilter
@@ -193,9 +170,10 @@ public:
     Private() : filters(), appearanceFilters(), model(this) {}
     void clear()
     {
+        model.beginResetModel();
         filters.clear();
         appearanceFilters.clear();
-        model.reset();
+        model.endResetModel();
     }
 
     std::vector<std::shared_ptr<KeyFilter>> filters;
@@ -320,7 +298,7 @@ const std::shared_ptr<KeyFilter> &KeyFilterManager::fromModelIndex(const QModelI
 QModelIndex KeyFilterManager::toModelIndex(const std::shared_ptr<KeyFilter> &kf) const
 {
     if (!kf) {
-        return QModelIndex();
+        return {};
     }
     const auto pair = std::equal_range(d->filters.cbegin(), d->filters.cend(), kf, ByDecreasingSpecificity());
     const auto it = std::find(pair.first, pair.second, kf);
@@ -394,7 +372,7 @@ static QColor get_color(const std::vector<std::shared_ptr<KeyFilter>> &filters,
                                     && (filter.get()->*fun)().isValid();
                                  });
     if (it == filters.cend()) {
-        return QColor();
+        return {};
     } else {
         return (it->get()->*fun)();
     }
