@@ -2,37 +2,14 @@
     keyresolver.cpp
 
     This file is part of libkleopatra, the KDE keymanagement library
-    Copyright (c) 2004 Klarälvdalens Datakonsult AB
-    Copyright (c) 2018 Intevation GmbH
+    SPDX-FileCopyrightText: 2004 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2018 Intevation GmbH
 
     Based on kpgp.cpp
-    Copyright (C) 2001,2002 the KPGP authors
+    SPDX-FileCopyrightText: 2001, 2002 the KPGP authors
     See file libkdenetwork/AUTHORS.kpgp for details
 
-    Libkleopatra is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of the
-    License, or (at your option) any later version.
-
-    Libkleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <gpgme++/key.h>
@@ -92,7 +69,7 @@ public:
         if (!ValidSigningKey(key)) {
             return false;
         }
-        if (mCompliance == QStringLiteral("de-vs")) {
+        if (mCompliance == QLatin1String("de-vs")) {
             if (!Formatting::isKeyDeVs(key)) {
                 qCDebug(LIBKLEO_LOG) << "Rejected sig key" << key.primaryFingerprint()
                                      << "because it is not de-vs compliant.";
@@ -108,7 +85,7 @@ public:
             return false;
         }
 
-        if (mCompliance == QStringLiteral("de-vs")) {
+        if (mCompliance == QLatin1String("de-vs")) {
             if (!Formatting::isKeyDeVs(key)) {
                 qCDebug(LIBKLEO_LOG) << "Rejected enc key" << key.primaryFingerprint()
                                      << "because it is not de-vs compliant.";
@@ -435,7 +412,7 @@ public:
                 unresolvedSig << mSender;
             } else {
                 std::vector<GpgME::Key> resolvedSigKeys;
-                for (const auto &keys: mSigKeys) {
+                for (const auto &keys: qAsConst(mSigKeys)) {
                     for (const auto &key: keys) {
                         resolvedSigKeys.push_back(key);
                     }
@@ -454,7 +431,7 @@ public:
                 if (mFormat & AutoFormat) {
                     // In Auto Format we can now remove recipients that could
                     // be resolved either through CMS or PGP
-                    for (const auto &addr: mUnresolvedPGP) {
+                    for (const auto &addr: qAsConst(mUnresolvedPGP)) {
                         if (mUnresolvedCMS.contains(addr)) {
                             unresolvedRecp << addr;
                         }
@@ -578,7 +555,7 @@ public:
         Q_EMIT q->keysResolved(true, false);
     }
 
-    KeyResolver *q;
+    KeyResolver *const q;
     QString mSender;
     QStringList mRecipients;
     QStringList mHiddenRecipients;
