@@ -2,32 +2,9 @@
     models/keylistmodel.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2007 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "keylistmodel.h"
@@ -59,11 +36,15 @@
 #endif
 
 #include <algorithm>
-#include <vector>
 #include <map>
 #include <set>
 #include <iterator>
 
+#include <gpgme++/gpgmepp_version.h>
+#if GPGMEPP_VERSION >= 0x10E00 // 1.14.0
+# define GPGME_HAS_REMARKS
+#endif
+
 using namespace GpgME;
 using namespace Kleo;
 
@@ -72,14 +53,12 @@ Q_DECLARE_METATYPE(GpgME::Key)
 class AbstractKeyListModel::Private
 {
 public:
-    Private() :
-        m_toolTipOptions(Formatting::Validity),
-        m_useKeyCache(false),
-        m_secretOnly(false) {}
-    int m_toolTipOptions;
+    int m_toolTipOptions = Formatting::Validity;
     mutable QHash<const char *, QVariant> prettyEMailCache;
-    bool m_useKeyCache;
-    bool m_secretOnly;
+    mutable QHash<const char *, QVariant> remarksCache;
+    bool m_useKeyCache = false;
+    bool m_secretOnly = false;
+    std::vector<GpgME::Key> m_remarkKeys;
 };
 AbstractKeyListModel::AbstractKeyListModel(QObject *p)
     : QAbstractItemModel(p), KeyListModelInterface(), d(new Private)
@@ -99,6 +78,16 @@ int AbstractKeyListModel::toolTipOptions() const
     return d->m_toolTipOptions;
 }
 
+void AbstractKeyListModel::setRemarkKeys(const std::vector<GpgME::Key> &keys)
+{
+    d->m_remarkKeys = keys;
+}
+
+std::vector<GpgME::Key> AbstractKeyListModel::remarkKeys() const
+{
+    return d->m_remarkKeys;
+}
+
 Key AbstractKeyListModel::key(const QModelIndex &idx) const
 {
     if (idx.isValid()) {
@@ -124,7 +113,7 @@ std::vector<Key> AbstractKeyListModel::keys(const QList<QModelIndex> &indexes) c
 QModelIndex AbstractKeyListModel::index(const Key &key, int col) const
 {
     if (key.isNull() || col < 0 || col >= NumColumns) {
-        return QModelIndex();
+        return {};
     } else {
         return doMapFromKey(key, col);
     }
@@ -162,6 +151,7 @@ void AbstractKeyListModel::removeKey(const Key &key)
     }
     doRemoveKey(key);
     d->prettyEMailCache.remove(key.primaryFingerprint());
+    d->remarksCache.remove(key.primaryFingerprint());
 }
 
 QList<QModelIndex> AbstractKeyListModel::addKeys(const std::vector<Key> &keys)
@@ -180,6 +170,7 @@ void AbstractKeyListModel::clear()
     beginResetModel();
     doClear();
     d->prettyEMailCache.clear();
+    d->remarksCache.clear();
     endResetModel();
 }
 
@@ -198,9 +189,16 @@ QVariant AbstractKeyListModel::headerData(int section, Qt::Orientation o, int ro
             case Validity:         return i18n("User-IDs");
             case ValidFrom:        return i18n("Valid From");
             case ValidUntil:       return i18n("Valid Until");
-            case TechnicalDetails: return i18n("Details");
+            case TechnicalDetails: return i18n("Protocol");
             case ShortKeyID:       return i18n("Key-ID");
             case KeyID:            return i18n("Key-ID");
+            case Fingerprint:      return i18n("Fingerprint");
+            case Issuer:           return i18n("Issuer");
+            case SerialNumber:     return i18n("Serial Number");
+            case Origin:           return i18n("Origin");
+            case LastUpdate:       return i18n("Last Update");
+            case OwnerTrust:       return i18n("Certification Trust");
+            case Remarks:          return i18n("Tags");
             case NumColumns:;
             }
     return QVariant();
@@ -270,13 +268,59 @@ QVariant AbstractKeyListModel::data(const QModelIndex &index, int role) const
             return Formatting::prettyID(key.keyID());
         case Summary:
             return Formatting::summaryLine(key);
+        case Fingerprint:
+            return Formatting::prettyID(key.primaryFingerprint());
+        case Issuer:
+            return QString::fromUtf8(key.issuerName());
+        case Origin:
+            return Formatting::origin(key.origin());
+        case LastUpdate:
+            return Formatting::dateString(key.lastUpdate());
+        case SerialNumber:
+            return QString::fromUtf8(key.issuerSerial());
+        case OwnerTrust:
+            return Formatting::ownerTrustShort(key.ownerTrust());
+        case Remarks:
+#ifdef GPGME_HAS_REMARKS
+            {
+                const char *const fpr = key.primaryFingerprint();
+                if (fpr && key.protocol() == GpgME::OpenPGP && key.numUserIDs() &&
+                        d->m_remarkKeys.size()) {
+                    if (!(key.keyListMode() & GpgME::SignatureNotations)) {
+                        return i18n("Loading...");
+                    }
+                    const QHash<const char *, QVariant>::const_iterator it = d->remarksCache.constFind(fpr);
+                    if (it != d->remarksCache.constEnd()) {
+                        return *it;
+                    } else {
+                        GpgME::Error err;
+                        const auto remarks = key.userID(0).remarks(d->m_remarkKeys, err);
+                        if (remarks.size() == 1) {
+                            const auto remark = QString::fromStdString(remarks[0]);
+                            return d->remarksCache[fpr] = remark;
+                        } else {
+                            QStringList remarkList;
+                            remarkList.reserve(remarks.size());
+                            for (const auto &rem: remarks) {
+                                remarkList << QString::fromStdString(rem);
+                            }
+                            const auto remark = remarkList.join(QStringLiteral("; "));
+                            return d->remarksCache[fpr] = remark;
+                        }
+                    }
+                } else {
+                    return QVariant();
+                }
+            }
+#endif
+            return QVariant();
         case NumColumns:
             break;
         }
     } else if (role == Qt::ToolTipRole) {
         return Formatting::toolTip(key, toolTipOptions());
     } else if (role == Qt::FontRole) {
-        return KeyFilterManager::instance()->font(key, (column == ShortKeyID || column == KeyID) ? QFont(QStringLiteral("monospace")) : QFont());
+        return KeyFilterManager::instance()->font(key, (column == ShortKeyID || column == KeyID || column == Fingerprint) ? QFont(QStringLiteral("monospace")) : QFont());
     } else if (role == Qt::DecorationRole) {
         return column == Icon ? returnIfValid(KeyFilterManager::instance()->icon(key)) : QVariant();
     } else if (role == Qt::BackgroundRole) {
@@ -427,7 +471,7 @@ QModelIndex FlatKeyListModel::doMapFromKey(const Key &key, int col) const
         = std::lower_bound(mKeysByFingerprint.begin(), mKeysByFingerprint.end(),
                            key, _detail::ByFingerprint<std::less>());
     if (it == mKeysByFingerprint.end() || !_detail::ByFingerprint<std::equal_to>()(*it, key)) {
-        return QModelIndex();
+        return {};
     } else {
         return createIndex(it - mKeysByFingerprint.begin(), col);
     }
@@ -441,7 +485,7 @@ QList<QModelIndex> FlatKeyListModel::doAddKeys(const std::vector<Key> &keys)
         return QList<QModelIndex>();
     }
 
-    for (std::vector<Key>::const_iterator it = keys.begin(), end = keys.end(); it != end; ++it) {
+    for (auto it = keys.begin(), end = keys.end(); it != end; ++it) {
 
         // find an insertion point:
         const std::vector<Key>::iterator pos = std::upper_bound(mKeysByFingerprint.begin(), mKeysByFingerprint.end(), *it, _detail::ByFingerprint<std::less>());
@@ -518,7 +562,7 @@ QModelIndex HierarchicalKeyListModel::index(int row, int col, const QModelIndex
 {
 
     if (row < 0 || col < 0 || col >= NumColumns) {
-        return QModelIndex();
+        return {};
     }
 
     // toplevel item:
@@ -547,7 +591,7 @@ QModelIndex HierarchicalKeyListModel::parent(const QModelIndex &idx) const
 {
     const Key key = this->key(idx);
     if (key.isNull() || key.isRoot()) {
-        return QModelIndex();
+        return {};
     }
     const std::vector<Key>::const_iterator it
         = qBinaryFind(mKeysByFingerprint.begin(), mKeysByFingerprint.end(),
@@ -585,7 +629,7 @@ QModelIndex HierarchicalKeyListModel::doMapFromKey(const Key &key, int col) cons
 {
 
     if (key.isNull()) {
-        return QModelIndex();
+        return {};
     }
 
     const char *issuer_fpr = cleanChainID(key);
@@ -754,8 +798,8 @@ QList<QModelIndex> HierarchicalKeyListModel::doAddKeys(const std::vector<Key> &k
         // Step 1: For new keys, remove children from toplevel:
 
         if (!keyAlreadyExisted) {
-            std::vector<Key>::iterator last = mTopLevels.begin();
-            std::vector<Key>::iterator lastFP = mKeysByFingerprint.begin();
+            auto last = mTopLevels.begin();
+            auto lastFP = mKeysByFingerprint.begin();
 
             for (const Key &k : qAsConst(children)) {
                 last = qBinaryFind(last, mTopLevels.end(), k, _detail::ByFingerprint<std::less>());
