@@ -2,33 +2,10 @@
     directoryserviceswidget.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2001,2002,2004 Klarävdalens Datakonsult AB
-    Copyright (c) 2017 Bundesamnt für Sicherheit in der Informationstechnik
+    SPDX-FileCopyrightText: 2001, 2002, 2004 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2017 Bundesamnt für Sicherheit in der Informationstechnik
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "directoryserviceswidget.h"
@@ -42,10 +19,7 @@
 #include <QItemDelegate>
 #include <QAbstractTableModel>
 #include <QSpinBox>
-#include <QComboBox>
 #include <QHeaderView>
-#include <QMenu>
-#include <QAction>
 
 #include <vector>
 
@@ -142,8 +116,8 @@ static unsigned short display_port(const QUrl &url)
 static QRect calculate_geometry(const QRect &cell, const QSize &sizeHint)
 {
     const int height = qMax(cell.height(), sizeHint.height());
-    return QRect(cell.left(), cell.top() - (height - cell.height()) / 2,
-                 cell.width(), height);
+    return {cell.left(), cell.top() - (height - cell.height()) / 2,
+                 cell.width(), height};
 }
 
 /* The Model contains a bit historic cruft because in the past it was
@@ -170,7 +144,7 @@ public:
             return;
         }
         m_x509ReadOnly = ro;
-        for (unsigned int row = 0, end = rowCount(); row != end; ++row) {
+        for (int row = 0, end = rowCount(); row != end; ++row) {
             Q_EMIT dataChanged(index(row, 0), index(row, NumColumns));
         }
     }
@@ -215,7 +189,7 @@ public:
     QModelIndex duplicateRow(unsigned int row)
     {
         if (row >= m_items.size()) {
-            return QModelIndex();
+            return {};
         }
 
         beginInsertRows(QModelIndex(), row + 1, row + 1);
@@ -358,7 +332,7 @@ public:
 private:
     QWidget *createPortWidget(QWidget *parent) const
     {
-        QSpinBox *sb = new QSpinBox(parent);
+        auto *sb = new QSpinBox(parent);
         sb->setRange(1, USHRT_MAX);   // valid port numbers
         return sb;
     }
@@ -401,8 +375,8 @@ public:
         connect(&model, &QAbstractItemModel::dataChanged, q, &DirectoryServicesWidget::changed);
         connect(&model, &QAbstractItemModel::rowsInserted, q, &DirectoryServicesWidget::changed);
         connect(&model, &QAbstractItemModel::rowsRemoved, q, &DirectoryServicesWidget::changed);
-        connect(ui.treeView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                q, SLOT(slotSelectionChanged()));
+        connect(ui.treeView->selectionModel(), &QItemSelectionModel::selectionChanged,
+                q, [this]() { slotSelectionChanged(); });
         connect(ui.pgpKeyserver, &QLineEdit::textChanged, q, &DirectoryServicesWidget::changed);
 
         slotShowUserAndPasswordToggled(false);
@@ -538,7 +512,7 @@ QList<QUrl> DirectoryServicesWidget::openPGPServices() const
 {
     QList<QUrl> result;
     const QString pgpStr = d->ui.pgpKeyserver->text();
-    if (pgpStr.contains(QStringLiteral("://"))) {
+    if (pgpStr.contains(QLatin1String("://"))) {
         // Maybe validate here? Otoh maybe gnupg adds support for more schemes
         // then we know about in the future.
         result.push_back(QUrl::fromUserInput(pgpStr));
