@@ -2,32 +2,9 @@
     messagebox.cpp
 
     This file is part of libkleopatra, the KDE keymanagement library
-    Copyright (c) 2004 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2004 Klarälvdalens Datakonsult AB
 
-    Libkleopatra is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of the
-    License, or (at your option) any later version.
-
-    Libkleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "messagebox.h"
@@ -44,9 +21,8 @@
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <KLocalizedString>
-#include <kguiitem.h>
+#include <KGuiItem>
 
-#include <QTextStream>
 
 #include <gpg-error.h>
 #include <KSharedConfig>
@@ -93,7 +69,7 @@ void MessageBox::auditLog(QWidget *parent, const Job *job, const QString &captio
 // static
 void MessageBox::auditLog(QWidget *parent, const QString &log, const QString &caption)
 {
-    AuditLogViewer *const alv = new AuditLogViewer(log, parent);
+    auto *const alv = new AuditLogViewer(log, parent);
     alv->setAttribute(Qt::WA_DeleteOnClose);
     alv->setObjectName(QStringLiteral("alv"));
     alv->setWindowTitle(caption);
